@@ -14,7 +14,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-from typing import Iterable
+from typing import List
 
 from .connector import connect
 from .instance_connection_manager import CloudSQLConnectionError, IPTypes
@@ -29,4 +29,4 @@ try:
 except ImportError:
     import pkgutil
 
-    __path__: Iterable[str] = pkgutil.extend_path(__path__, __name__)
+    __path__: List[str] = pkgutil.extend_path(__path__, __name__)
