@@ -40,7 +40,7 @@ async def _get_metadata(
     authority of the Cloud SQL Instance.
 
     :type credentials: google.oauth2.service_account.Credentials
-    :param service:
+    :param credentials:
         A credentials object created from the google-auth Python library.
         Must have the SQL Admin API scopes. For more info check out
         https://google-auth.readthedocs.io/en/latest/.
@@ -49,8 +49,8 @@ async def _get_metadata(
     :param project:
         A string representing the name of the project.
 
-    :type inst_name: str
-    :param project: A string representing the name of the instance.
+    :type instance: str
+    :param instance: A string representing the name of the instance.
 
     :rtype: Dict[str: Union[Dict, str]]
     :returns: Returns a dictionary containing a dictionary of all IP
@@ -67,8 +67,8 @@ async def _get_metadata(
     ):
         raise TypeError(
             "Arguments must be as follows: "
-            + "service (googleapiclient.discovery.Resource), "
-            + "proj_name (str) and inst_name (str)."
+            + "credentials (google.oauth2.service_account.Credentials), "
+            + "project (str) and instance (str)."
         )
 
     if not credentials.valid:
@@ -79,7 +79,7 @@ async def _get_metadata(
         "Authorization": "Bearer {}".format(credentials.token),
     }
 
-    url = "https://www.googleapis.com/sql/{}/projects/{}/instances/{}".format(
+    url = "https://sqladmin.googleapis.com/sql/{}/projects/{}/instances/{}/connectSettings".format(
         _sql_api_version, project, instance
     )
 
@@ -154,16 +154,14 @@ async def _get_ephemeral(
         "Authorization": f"Bearer {credentials.token}",
     }
 
-    url = "https://www.googleapis.com/sql/{}/projects/{}/instances/{}/createEphemeral".format(
+    url = "https://sqladmin.googleapis.com/sql/{}/projects/{}/instances/{}:generateEphemeralCert".format(
         _sql_api_version, project, instance
     )
 
     data = {"public_key": pub_key}
 
     if enable_iam_auth:
-        # TODO: remove this once issue with OAuth2 Tokens is resolved.
-        # See https://github.com/GoogleCloudPlatform/cloud-sql-python-connector/issues/137
-        data["access_token"] = credentials.token.rstrip(".")
+        data["access_token"] = credentials.token
 
     resp = await client_session.post(
         url, headers=headers, json=data, raise_for_status=True
@@ -171,4 +169,4 @@ async def _get_ephemeral(
 
     ret_dict = json.loads(await resp.text())
 
-    return ret_dict["cert"]
+    return ret_dict["ephemeralCert"]["cert"]
